add_python_import

Function add_python_import 

pub fn add_python_import(import: &PythonImport) -> Vec<DCPythonImport>
‘Untangles’ a ast::PythonImport, which represents a python import line, into one or more DCPythonImport structures, which represent symbol imports from a python module (with view suffixes applied) and adds them to the DC tree.